==> stew-3.1.2.zip: Stew/src/net/argius/stew/ui/window/TextSearch.java <==
/*
 *  Copyright 2010 argius
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package net.argius.stew.ui.window;

import java.awt.*;
import java.util.regex.*;

import javax.swing.text.*;
import javax.swing.text.Highlighter.*;

/**
 * eLXg̃C^tF[XB
 */
public interface TextSearch {

    /**
     * eLXgB
     * @param matcher eLXgv
     * @return Ɉvꍇ <code>true</code>AłȂꍇ <code>false</code>
     */
    boolean search(Matcher matcher);

    /**
     * ԂZbgB
     */
    void reset();

    /**
     * }b`OB
     */
    public final class Matcher {

        private Pattern pattern;
        private String string;
        private boolean useRegularExpression;
        private boolean ignoreCase;
        private boolean backward;
        private boolean continuously;
        private int start;
        private int end;

        /**
         * RXgN^B
         * @param target Ώە܂̓p^[
         * @param useRegularExpression K\gp邩ǂ
         * @param ignoreCase 啶Ə̈Ⴂ𖳎邩ǂ
         */
        public Matcher(String target, boolean useRegularExpression, boolean ignoreCase) {
            if (useRegularExpression) {
                int option = (ignoreCase) ? Pattern.CASE_INSENSITIVE : 0;
                this.pattern = Pattern.compile(target, option);
                this.string = target;
            } else if (ignoreCase) {
                this.string = target.toUpperCase();
            } else {
                this.string = target;
            }
            this.useRegularExpression = useRegularExpression;
            this.ignoreCase = ignoreCase;
        }

        /**
         * HighlightPainter̎擾B
         * @return HighlightPainter
         */
        public HighlightPainter getHighlightPainter() {
            return new DefaultHighlighter.DefaultHighlightPainter(Color.decode("#33dd66"));
        }

        /**
         * backward̎擾B
         * @return backward
         */
        public boolean isBackward() {
            return backward;
        }

        /**
         * backward̐ݒB
         * @param backward backward
         */
        public void setBackward(boolean backward) {
            this.backward = backward;
        }

        /**
         * continuously̎擾B
         * @return continuously
         */
        public boolean isContinuously() {
            return continuously;
        }

        /**
         * continuously̐ݒB
         * @param continuously continuously
         */
        public void setContinuously(boolean continuously) {
            this.continuously = continuously;
        }

        /**
         * B
         * @param value l
         * @return ꍇ <code>true</code>AłȂ <code>false</code>
         */
        public boolean find(String value) {
            return find(value, 0);
        }

        /**
         * B
         * @param value l
         * @param start Jnʒu
         * @return ꍇ <code>true</code>AłȂ <code>false</code>
         */
        public boolean find(String value, int start) {
            this.start = -1;
            this.end = -1;
            boolean found;
            if (useRegularExpression) {
                java.util.regex.Matcher m = pattern.matcher(value);
                found = m.find(start);
                if (found) {
                    this.start = m.start();
                    this.end = m.end();
                }
            } else {
                String v = (ignoreCase) ? value.toUpperCase() : value;
                int index = v.indexOf(string, start);
                found = index >= start;
                if (found) {
                    this.start = index;
                    this.end = index + string.length();
                }
            }
            return found;
        }

        /**
         * start̎擾B
         * @return start
         */
        public int getStart() {
            return start;
        }

        /**
         * end̎擾B
         * @return end
         */
        public int getEnd() {
            return end;
        }

    }

}

==> stew-4.0.1.zip: Stew/src/net/argius/stew/ui/window/TextSearch.java <==
package net.argius.stew.ui.window;

import java.awt.*;
import java.util.regex.*;

import javax.swing.text.*;
import javax.swing.text.Highlighter.HighlightPainter;

/**
 * The interface for text search.
 */
public interface TextSearch {

    /**
     * Searches a text.
     * @param matcher
     * @return true if matched, otherwise false
     */
    boolean search(Matcher matcher);

    /**
     * Resets searching.
     */
    void reset();

    /**
     * The Matcher for TextSearch.
     */
    public final class Matcher {

        private Pattern pattern;
        private String string;
        private boolean useRegularExpression;
        private boolean ignoreCase;
        private boolean backward;
        private boolean continuously;
        private int start;
        private int end;

        /**
         * A constructor.
         * @param target
         * @param useRegularExpression
         * @param ignoreCase
         */
        public Matcher(String target, boolean useRegularExpression, boolean ignoreCase) {
            if (useRegularExpression) {
                int option = (ignoreCase) ? Pattern.CASE_INSENSITIVE : 0;
                this.pattern = Pattern.compile(target, option);
                this.string = target;
            } else if (ignoreCase) {
                this.string = target.toUpperCase();
            } else {
                this.string = target;
            }
            this.useRegularExpression = useRegularExpression;
            this.ignoreCase = ignoreCase;
        }

        /**
         * Returns HighlightPainter.
         * @return
         */
        public static HighlightPainter getHighlightPainter() {
            return new DefaultHighlighter.DefaultHighlightPainter(Color.decode("#33dd66"));
        }

        /**
         * Returns backword or not.
         * @return
         */
        public boolean isBackward() {
            return backward;
        }

        /**
         * Sets backword or not.
         * @param backward
         */
        public void setBackward(boolean backward) {
            this.backward = backward;
        }

        /**
         * Returns continuously or not.
         * @return
         */
        public boolean isContinuously() {
            return continuously;
        }

        /**
         * Sets continuously or not.
         * @param continuously
         */
        public void setContinuously(boolean continuously) {
            this.continuously = continuously;
        }

        /**
         * Finds the text.
         * @param value
         * @return true if text was found, otherwise false
         */
        public boolean find(String value) {
            return find(value, 0);
        }

        /**
         * Finds the text.
         * @param value
         * @param start
         * @return true if text was found, otherwise false
         */
        public boolean find(String value, int start) {
            this.start = -1;
            this.end = -1;
            boolean found;
            if (useRegularExpression) {
                java.util.regex.Matcher m = pattern.matcher(value);
                found = m.find(start);
                if (found) {
                    this.start = m.start();
                    this.end = m.end();
                }
            } else {
                String v = (ignoreCase) ? value.toUpperCase() : value;
                int index = v.indexOf(string, start);
                found = index >= start;
                if (found) {
                    this.start = index;
                    this.end = index + string.length();
                }
            }
            return found;
        }

        /**
         * Returns this start position.
         * @return
         */
        public int getStart() {
            return start;
        }

        /**
         * Returns this end position.
         * @return
         */
        public int getEnd() {
            return end;
        }

    }

}
